#!/bin/bash
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

export CFLAGS="-march=armv8-a+crc -mtune=cortex-a72 -Os -pipe"
export CXXFLAGS="-march=armv8-a+crc -mtune=cortex-a72 -Os -pipe -fno-exceptions -fno-rtti"

P=jbig2dec
V=0.19
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc libpng-dev "
for Z in $LIST 
    do 
    su -c "tce-load -i $Z" $USER
done

# list may have more than loaded
cd /usr/local/lib
rm -rf *.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/plugin/*.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/*.la
rm -rf gprofng/*.la 
rm -rf python3.8/site-packages/*.la
rm -rf pkcs11/*.la
rm -rf cairo/*.la
rm -rf gtk-2.0/modules/*.la
rm -rf gtk-2.0/2.10.0/printbackends/*.la
rm -rf gtk-2.0/2.10.0/immodules/*.la
rm -rf gtk-2.0/2.10.0/engines/*.la
rm -rf imlib2/loaders/*.la
rm -rf imlib2/filters/*.la
rm -rf gdk-pixbuf-2.0/2.10.0/loaders/*.la
cd /tmp
rm -rf /usr/lib/*.la

URL=https://github.com/ArtifexSoftware/ghostpdl-downloads/releases/download
su -c "/usr/local/bin/wget -nc --no-check-certificate \
$URL/gs9530/$P-$V.tar.gz   " $USER
tar xvf $SRC*gz
cd $SRC
./configure --prefix=/usr/local 
make -j5 # about 15s
make install-strip DESTDIR=/tmp/$P
cd /tmp

# dev
#####
mkdir -p $P-dev/usr/local/lib
mv $P/usr/local/include $P-dev/usr/local/
mv $P/usr/local/lib/pkgconfig $P-dev/usr/local/lib
rm -rf  $P/usr/local/lib/*la 
mv $P/usr/local/lib/*.a $P-dev/usr/local/lib

# main 
######
rm -rf $P/usr/local/share/man
mkdir -p $P/usr/local/share/doc/$P
# needs 2 licences one is for ghostscript
cp $SRC/LICENSE $P/usr/local/share/doc/$P
cp $SRC/COPYING $P/usr/local/share/doc/$P

# TCZ them
#######
LIST="$P $P-dev "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          jbig2dec-dev.tcz
Description:    dev files
Version:        0.19
Author:         Artifex Software Inc.
Original-site:  https://www.jbig2dec.com/
Copying-policy: AFFERO GENERAL PUBLIC LICENSE v3 (mainly)
Size:           68K
Extension_by:   aus9
Tags:           ghostscript 
Comments:       make dep of ghostscript 

Change-log:     2023/06/12 v 0.19 on 14.x
Current:        2023/06/12                ' > $P-dev.tcz.info

echo 'jbig2dec.tcz
libpng-dev.tcz     ' > $P-dev.tcz.dep

echo 'Title:          jbig2dec.tcz
Description:    image decoder 
Version:        0.19
Author:         Artifex Software Inc.
Original-site:  https://www.jbig2dec.com/
Copying-policy: AFFERO GENERAL PUBLIC LICENSE v3 (mainly)
Size:           76K
Extension_by:   aus9
Tags:           ghostscript 
Comments:       LICENSE allows compile/distribute with ghostscipt
                COPYING allows distribution 

Change-log:     2023/06/12 v 0.19 on 14.x
Current:        2023/06/12                ' > $P.tcz.info

readelf -d $P/usr/local/bin/*  | grep 'NEEDED' # remove below duplicates TCBs
#[libjbig2dec.so.0] this TCE
#[libpng16.so.16]png
readelf -d $P/usr/local/lib/*  | grep 'NEEDED'

echo 'libpng.tcz' > $P.tcz.dep

submitqc --libs

rm -rf *.zsync

